AcpAgent class final

Stable ACP v1 implementation of the protocol-neutral Agent API.

Implemented types
Available extensions

Properties

authenticationMethods List<AgentAuthenticationMethod>
final
authenticationMethods List<AgentAuthenticationMethod>?

Available on Agent, provided by the AgentAuthenticationDiscoveryAccess extension

no setter
capabilities AgentCapabilities
final
diagnostics Stream<String>
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
info AgentInfo
final
isOpen bool
no setter
protocol AgentProtocol
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

authenticate(AgentAuthentication selection) Future<void>
override
close() Future<void>
override
createSession(AgentSessionOptions options) Future<AgentSession>
override
deleteSession(AgentSessionId sessionId) Future<void>
override
listSessions([AgentSessionListOptions options = const semantic.AgentSessionListOptions()]) Future<AgentSessionPage>
override
logout() Future<void>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resumeSession(AgentSessionResumeOptions options) Future<AgentSession>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

connect(AcpTransport transport, {AgentClientServices client = const AgentClientServices(), AgentInfo clientInfo = const semantic.AgentInfo(name: 'agent_harness', version: agentHarnessVersion)}) Future<AcpAgent>
Initializes an already-created transport, primarily for custom transports and deterministic integration tests.
launch(AgentLaunchCommand command, {required ProcessExecutor executor, AgentClientServices client = const AgentClientServices(), AgentInfo clientInfo = const semantic.AgentInfo(name: 'agent_harness', version: agentHarnessVersion)}) Future<AcpAgent>