AcpError class final

ACP stable-v1 Error.

Source: /$defs/Error. JSON-RPC error object.

Annotations
  • @immutable

Constructors

AcpError({required ErrorCode code, required String message, Object? data})
AcpError.fromMap(Map<Object?, Object?> value)
factory

Properties

code ErrorCode
final
data Object?
final
hashCode int
The hash code for this object.
no setterinherited
message String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({Object? code = _acpCopyWithAbsent, Object? message = _acpCopyWithAbsent, Object? data = _acpCopyWithAbsent}) AcpError
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() AcpJsonMap
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited