isNull property
bool
get
isNull
Whether this field was explicitly null on the wire.
Implementation
bool get isNull => this is AcpFieldNull<T>;
Whether this field was explicitly null on the wire.
bool get isNull => this is AcpFieldNull<T>;