AcpFileSystemService class abstract interface

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
readTextFile(ReadTextFileRequest request) Future<ReadTextFileResponse>
toString() String
A string representation of this object.
inherited
writeTextFile(WriteTextFileRequest request) Future<WriteTextFileResponse>

Operators

operator ==(Object other) bool
The equality operator.
inherited