AcpV1Connection class final
Constructors
- AcpV1Connection(AcpTransport transport, {AgentClientServices services = const AgentClientServices()})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- initializeResponse → InitializeResponse?
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
sessionUpdates
→ Stream<
AcpV1SessionUpdate> -
no setter
- state → AcpV1ConnectionState
-
no setter
Methods
-
authenticate(
AuthenticateRequest request) → Future< AuthenticateResponse> -
cancel(
CancelNotification notification) → Future< void> -
close(
) → Future< void> -
closeSession(
CloseSessionRequest request) → Future< CloseSessionResponse> -
deleteSession(
DeleteSessionRequest request) → Future< DeleteSessionResponse> -
initialize(
InitializeRequest request) → Future< InitializeResponse> -
listSessions(
ListSessionsRequest request) → Future< ListSessionsResponse> -
loadSession(
LoadSessionRequest request) → Future< LoadSessionResponse> -
logout(
LogoutRequest request) → Future< LogoutResponse> -
newSession(
NewSessionRequest request) → Future< NewSessionResponse> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
prompt(
PromptRequest request) → Future< PromptResponse> -
resumeSession(
ResumeSessionRequest request) → Future< ResumeSessionResponse> -
setSessionConfigOption(
SetSessionConfigOptionRequest request) → Future< SetSessionConfigOptionResponse> -
setSessionMode(
SetSessionModeRequest request) → Future< SetSessionModeResponse> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited