Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- authenticate → const String
- cancel_request → const String
- elicitation_complete → const String
- elicitation_create → const String
- fs_read_text_file → const String
- fs_write_text_file → const String
- initialize → const String
- logout → const String
- session_cancel → const String
- session_close → const String
- session_delete → const String
- session_list → const String
- session_load → const String
- session_new → const String
- session_prompt → const String
- session_request_permission → const String
- session_resume → const String
- session_set_config_option → const String
- session_set_mode → const String
- session_update → const String
- terminal_create → const String
- terminal_kill → const String
- terminal_output → const String
- terminal_release → const String
- terminal_wait_for_exit → const String