AcpWireDecodeException class final

Thrown when an ACP wire object cannot be decoded.

Inheritance
Annotations
  • @immutable

Constructors

AcpWireDecodeException(String message, {Object? cause, StackTrace? stackTrace, int? version, String? definition})
const

Properties

cause Object?
finalinherited
definition String?
finalinherited
hashCode int
The hash code for this object.
no setterinherited
message String
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stackTrace StackTrace?
finalinherited
version int?
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited