AcpWireErrorDetail class final

ACK-independent diagnostic detail for a failure at the ACP wire boundary.

Annotations
  • @immutable

Constructors

AcpWireErrorDetail({required String path, required String message, int? version, String? definition, Iterable<AcpWireErrorDetail> details = const []})

Properties

definition String?
ACP definition whose generated schema reported this detail.
final
details List<AcpWireErrorDetail>
More specific failures nested below this one.
final
hashCode int
The hash code for this object.
no setterinherited
message String
Human-readable description of the failure.
final
path String
URI-fragment form of the RFC 6901 pointer to the failed wire value.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
version int?
ACP protocol version whose generated schema reported this detail.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited