AgentLaunchCommand class final

Annotations
  • @immutable

Constructors

AgentLaunchCommand({required String executable, List<String> arguments = const <String>[], Map<String, String> environment = const <String, String>{}, String? workingDirectory})

Properties

arguments List<String>
final
environment Map<String, String>
final
executable String
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
workingDirectory String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited