AgentNotification class final

ACP stable-v1 AgentNotification.

Source: /$defs/AgentNotification. A JSON-RPC notification object.

Annotations
  • @immutable

Constructors

AgentNotification({required String method, Object? params})
AgentNotification.fromMap(Map<Object?, Object?> value)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
method String
final
params Object?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({Object? method = _acpCopyWithAbsent, Object? params = _acpCopyWithAbsent}) AgentNotification
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() AcpJsonMap
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited