AgentRequest class final

ACP stable-v1 AgentRequest.

Source: /$defs/AgentRequest. A JSON-RPC request object.

Annotations
  • @immutable

Constructors

AgentRequest({required RequestId id, required String method, Object? params})
AgentRequest.fromMap(Map<Object?, Object?> value)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
id RequestId
final
method String
final
params Object?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({Object? id = _acpCopyWithAbsent, Object? method = _acpCopyWithAbsent, Object? params = _acpCopyWithAbsent}) AgentRequest
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() AcpJsonMap
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited