AgentResponseError class final

Inheritance
Annotations
  • @immutable

Constructors

AgentResponseError({required RequestId id, required AcpError error})
AgentResponseError.fromMap(Map<Object?, Object?> value)
factory

Properties

error AcpError
final
hashCode int
The hash code for this object.
no setterinherited
id RequestId
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({Object? id = _acpCopyWithAbsent, Object? error = _acpCopyWithAbsent}) AgentResponseError
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() AcpJsonMap
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited