Annotations class final

ACP stable-v1 Annotations.

Source: /$defs/Annotations. Optional annotations for the client. The client can use annotations to inform how objects are used or displayed

Annotations
  • @immutable

Constructors

Annotations({List<Role>? audience, String? lastModified, num? priority, AcpJsonMap? meta})
Annotations.fromMap(Map<Object?, Object?> value)
factory

Properties

audience List<Role>?
final
hashCode int
The hash code for this object.
no setterinherited
lastModified String?
final
meta AcpJsonMap?
final
priority num?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({Object? audience = _acpCopyWithAbsent, Object? lastModified = _acpCopyWithAbsent, Object? priority = _acpCopyWithAbsent, Object? meta = _acpCopyWithAbsent}) Annotations
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() AcpJsonMap
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited