AvailableCommandsUpdate class final

ACP stable-v1 AvailableCommandsUpdate.

Source: /$defs/AvailableCommandsUpdate. Available commands are ready or have changed

Annotations
  • @immutable

Constructors

AvailableCommandsUpdate({required List<AvailableCommand> availableCommands, AcpJsonMap? meta})
AvailableCommandsUpdate.fromMap(Map<Object?, Object?> value)
factory

Properties

availableCommands List<AvailableCommand>
final
hashCode int
The hash code for this object.
no setterinherited
meta AcpJsonMap?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({Object? availableCommands = _acpCopyWithAbsent, Object? meta = _acpCopyWithAbsent}) AvailableCommandsUpdate
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() AcpJsonMap
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited