BlobResourceContents class final

ACP stable-v1 BlobResourceContents.

Source: /$defs/BlobResourceContents. Binary resource contents.

Annotations
  • @immutable

Constructors

BlobResourceContents({required String blob, String? mimeType, required String uri, AcpJsonMap? meta})
BlobResourceContents.fromMap(Map<Object?, Object?> value)
factory

Properties

blob String
final
hashCode int
The hash code for this object.
no setterinherited
meta AcpJsonMap?
final
mimeType String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
uri String
final

Methods

copyWith({Object? blob = _acpCopyWithAbsent, Object? mimeType = _acpCopyWithAbsent, Object? uri = _acpCopyWithAbsent, Object? meta = _acpCopyWithAbsent}) BlobResourceContents
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() AcpJsonMap
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited