CancelRequestNotification class final

ACP stable-v1 CancelRequestNotification.

Source: /$defs/CancelRequestNotification. Notification to cancel an ongoing request.

Annotations
  • @immutable

Constructors

CancelRequestNotification({required RequestId requestId, AcpJsonMap? meta})
CancelRequestNotification.fromMap(Map<Object?, Object?> value)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
meta AcpJsonMap?
final
requestId RequestId
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({Object? requestId = _acpCopyWithAbsent, Object? meta = _acpCopyWithAbsent}) CancelRequestNotification
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() AcpJsonMap
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited