ClientResponseResult class final

Inheritance
Annotations
  • @immutable

Constructors

ClientResponseResult({required RequestId id, required Object result})
ClientResponseResult.fromMap(Map<Object?, Object?> value)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
id RequestId
final
result Object
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({Object? id = _acpCopyWithAbsent, Object? result = _acpCopyWithAbsent}) ClientResponseResult
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() AcpJsonMap
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited