ClientSessionCapabilities class final

ACP stable-v1 ClientSessionCapabilities.

Source: /$defs/ClientSessionCapabilities. Session-related capabilities supported by the client.

Annotations
  • @immutable

Properties

configOptions SessionConfigOptionsCapabilities?
final
hashCode int
The hash code for this object.
no setterinherited
meta AcpJsonMap?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({Object? configOptions = _acpCopyWithAbsent, Object? meta = _acpCopyWithAbsent}) ClientSessionCapabilities
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() AcpJsonMap
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited