CloseSessionRequest class final

ACP stable-v1 CloseSessionRequest.

Source: /$defs/CloseSessionRequest. Request parameters for closing an active session.

Annotations
  • @immutable

Constructors

CloseSessionRequest({required SessionId sessionId, AcpJsonMap? meta})
CloseSessionRequest.fromMap(Map<Object?, Object?> value)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
meta AcpJsonMap?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionId SessionId
final

Methods

copyWith({Object? sessionId = _acpCopyWithAbsent, Object? meta = _acpCopyWithAbsent}) CloseSessionRequest
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() AcpJsonMap
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited