CompleteElicitationNotification class final

ACP stable-v1 CompleteElicitationNotification.

Source: /$defs/CompleteElicitationNotification. Notification sent by the agent when a URL-based elicitation is complete.

Annotations
  • @immutable

Constructors

CompleteElicitationNotification({required ElicitationId elicitationId, AcpJsonMap? meta})
CompleteElicitationNotification.fromMap(Map<Object?, Object?> value)
factory

Properties

elicitationId ElicitationId
final
hashCode int
The hash code for this object.
no setterinherited
meta AcpJsonMap?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({Object? elicitationId = _acpCopyWithAbsent, Object? meta = _acpCopyWithAbsent}) CompleteElicitationNotification
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() AcpJsonMap
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited