ConfigOptionUpdate class final

ACP stable-v1 ConfigOptionUpdate.

Source: /$defs/ConfigOptionUpdate. Session configuration options have been updated.

Annotations
  • @immutable

Constructors

ConfigOptionUpdate({required List<SessionConfigOption> configOptions, AcpJsonMap? meta})
ConfigOptionUpdate.fromMap(Map<Object?, Object?> value)
factory

Properties

configOptions List<SessionConfigOption>
final
hashCode int
The hash code for this object.
no setterinherited
meta AcpJsonMap?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({Object? configOptions = _acpCopyWithAbsent, Object? meta = _acpCopyWithAbsent}) ConfigOptionUpdate
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() AcpJsonMap
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited