Content class final

ACP stable-v1 Content.

Source: /$defs/Content. Standard content block (text, images, resources).

Annotations
  • @immutable

Constructors

Content({required ContentBlock content, AcpJsonMap? meta})
Content.fromMap(Map<Object?, Object?> value)
factory

Properties

content ContentBlock
final
hashCode int
The hash code for this object.
no setterinherited
meta AcpJsonMap?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({Object? content = _acpCopyWithAbsent, Object? meta = _acpCopyWithAbsent}) Content
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() AcpJsonMap
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited