ContentBlockText class final

Inheritance
Annotations
  • @immutable

Constructors

ContentBlockText({required String type, Annotations? annotations, required String text, AcpJsonMap? meta})
ContentBlockText.fromMap(Map<Object?, Object?> value)
factory

Properties

annotations Annotations?
final
hashCode int
The hash code for this object.
no setterinherited
meta AcpJsonMap?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String
final
type String
final

Methods

copyWith({Object? type = _acpCopyWithAbsent, Object? annotations = _acpCopyWithAbsent, Object? text = _acpCopyWithAbsent, Object? meta = _acpCopyWithAbsent}) ContentBlockText
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() AcpJsonMap
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited