Cost class final

ACP stable-v1 Cost.

Source: /$defs/Cost. Cost information for a session.

Annotations
  • @immutable

Constructors

Cost({required num amount, required String currency, AcpJsonMap? meta})
Cost.fromMap(Map<Object?, Object?> value)
factory

Properties

amount num
final
currency String
final
hashCode int
The hash code for this object.
no setterinherited
meta AcpJsonMap?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({Object? amount = _acpCopyWithAbsent, Object? currency = _acpCopyWithAbsent, Object? meta = _acpCopyWithAbsent}) Cost
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() AcpJsonMap
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited