CreateElicitationRequestForm class final

Inheritance
Annotations
  • @immutable

Constructors

CreateElicitationRequestForm({required String message, AcpJsonMap? meta, required String mode, required ElicitationSchema requestedSchema, SessionId? sessionId, ToolCallId? toolCallId, RequestId? requestId})
CreateElicitationRequestForm.fromMap(Map<Object?, Object?> value)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
message String
final
meta AcpJsonMap?
final
mode String
final
requestedSchema ElicitationSchema
final
requestId RequestId?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionId SessionId?
final
toolCallId ToolCallId?
final

Methods

copyWith({Object? message = _acpCopyWithAbsent, Object? meta = _acpCopyWithAbsent, Object? mode = _acpCopyWithAbsent, Object? requestedSchema = _acpCopyWithAbsent, Object? sessionId = _acpCopyWithAbsent, Object? toolCallId = _acpCopyWithAbsent, Object? requestId = _acpCopyWithAbsent}) CreateElicitationRequestForm
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() AcpJsonMap
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited