CreateTerminalRequest class final

ACP stable-v1 CreateTerminalRequest.

Source: /$defs/CreateTerminalRequest. Request to create a new terminal and execute a command.

Annotations
  • @immutable

Constructors

CreateTerminalRequest({required SessionId sessionId, required String command, List<String>? args, List<EnvVariable>? env, String? cwd, int? outputByteLimit, AcpJsonMap? meta})
CreateTerminalRequest.fromMap(Map<Object?, Object?> value)
factory

Properties

args List<String>?
final
command String
final
cwd String?
final
env List<EnvVariable>?
final
hashCode int
The hash code for this object.
no setterinherited
meta AcpJsonMap?
final
outputByteLimit int?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionId SessionId
final

Methods

copyWith({Object? sessionId = _acpCopyWithAbsent, Object? command = _acpCopyWithAbsent, Object? args = _acpCopyWithAbsent, Object? env = _acpCopyWithAbsent, Object? cwd = _acpCopyWithAbsent, Object? outputByteLimit = _acpCopyWithAbsent, Object? meta = _acpCopyWithAbsent}) CreateTerminalRequest
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() AcpJsonMap
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited