DeleteSessionRequest class final

ACP stable-v1 DeleteSessionRequest.

Source: /$defs/DeleteSessionRequest. Request parameters for deleting an existing session from session/list.

Annotations
  • @immutable

Constructors

DeleteSessionRequest({required SessionId sessionId, AcpJsonMap? meta})
DeleteSessionRequest.fromMap(Map<Object?, Object?> value)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
meta AcpJsonMap?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionId SessionId
final

Methods

copyWith({Object? sessionId = _acpCopyWithAbsent, Object? meta = _acpCopyWithAbsent}) DeleteSessionRequest
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() AcpJsonMap
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited