Diff class final

ACP stable-v1 Diff.

Source: /$defs/Diff. A diff representing file modifications.

Annotations
  • @immutable

Constructors

Diff({required String path, String? oldText, required String newText, AcpJsonMap? meta})
Diff.fromMap(Map<Object?, Object?> value)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
meta AcpJsonMap?
final
newText String
final
oldText String?
final
path String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({Object? path = _acpCopyWithAbsent, Object? oldText = _acpCopyWithAbsent, Object? newText = _acpCopyWithAbsent, Object? meta = _acpCopyWithAbsent}) Diff
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() AcpJsonMap
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited