ElicitationAcceptAction class final
ACP stable-v1 ElicitationAcceptAction.
Source: /$defs/ElicitationAcceptAction.
The user accepted the elicitation and provided content.
- Annotations
-
- @immutable
Constructors
-
ElicitationAcceptAction({Map<
String, ElicitationContentValue> ? content}) -
ElicitationAcceptAction.fromMap(Map<
Object?, Object?> value) -
factory
Properties
-
content
→ Map<
String, ElicitationContentValue> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{Object? content = _acpCopyWithAbsent}) → ElicitationAcceptAction -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → AcpJsonMap -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited