ElicitationCapabilities class final

ACP stable-v1 ElicitationCapabilities.

Source: /$defs/ElicitationCapabilities. Elicitation capabilities supported by the client.

Annotations
  • @immutable

Properties

form ElicitationFormCapabilities?
final
hashCode int
The hash code for this object.
no setterinherited
meta AcpJsonMap?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
url ElicitationUrlCapabilities?
final

Methods

copyWith({Object? form = _acpCopyWithAbsent, Object? url = _acpCopyWithAbsent, Object? meta = _acpCopyWithAbsent}) ElicitationCapabilities
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() AcpJsonMap
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited