ElicitationFormMode class sealed

ACP stable-v1 ElicitationFormMode.

Source: /$defs/ElicitationFormMode. Form-based elicitation mode where the client renders a form from the provided schema.

Implementers
Annotations
  • @immutable

Constructors

ElicitationFormMode.fromMap(Map<Object?, Object?> value)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Object?
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited