ElicitationFormModeRequest class final

Inheritance
Annotations
  • @immutable

Constructors

ElicitationFormModeRequest({required ElicitationSchema requestedSchema, required RequestId requestId})
ElicitationFormModeRequest.fromMap(Map<Object?, Object?> value)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
requestedSchema ElicitationSchema
final
requestId RequestId
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({Object? requestedSchema = _acpCopyWithAbsent, Object? requestId = _acpCopyWithAbsent}) ElicitationFormModeRequest
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() AcpJsonMap
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited