ElicitationFormModeSession class final

Inheritance
Annotations
  • @immutable

Constructors

ElicitationFormModeSession({required ElicitationSchema requestedSchema, required SessionId sessionId, ToolCallId? toolCallId})
ElicitationFormModeSession.fromMap(Map<Object?, Object?> value)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
requestedSchema ElicitationSchema
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionId SessionId
final
toolCallId ToolCallId?
final

Methods

copyWith({Object? requestedSchema = _acpCopyWithAbsent, Object? sessionId = _acpCopyWithAbsent, Object? toolCallId = _acpCopyWithAbsent}) ElicitationFormModeSession
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() AcpJsonMap
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited