ElicitationPropertySchemaBoolean class final

Inheritance
Annotations
  • @immutable

Constructors

ElicitationPropertySchemaBoolean({required String type, String? title, String? description, bool? defaultValue, AcpJsonMap? meta})
ElicitationPropertySchemaBoolean.fromMap(Map<Object?, Object?> value)
factory

Properties

defaultValue bool?
final
description String?
final
hashCode int
The hash code for this object.
no setterinherited
meta AcpJsonMap?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String?
final
type String
final

Methods

copyWith({Object? type = _acpCopyWithAbsent, Object? title = _acpCopyWithAbsent, Object? description = _acpCopyWithAbsent, Object? defaultValue = _acpCopyWithAbsent, Object? meta = _acpCopyWithAbsent}) ElicitationPropertySchemaBoolean
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() AcpJsonMap
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited