ElicitationPropertySchemaNumber class final

Inheritance
Annotations
  • @immutable

Constructors

ElicitationPropertySchemaNumber({required String type, String? title, String? description, num? minimum, num? maximum, num? defaultValue, AcpJsonMap? meta})
ElicitationPropertySchemaNumber.fromMap(Map<Object?, Object?> value)
factory

Properties

defaultValue num?
final
description String?
final
hashCode int
The hash code for this object.
no setterinherited
maximum num?
final
meta AcpJsonMap?
final
minimum num?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String?
final
type String
final

Methods

copyWith({Object? type = _acpCopyWithAbsent, Object? title = _acpCopyWithAbsent, Object? description = _acpCopyWithAbsent, Object? minimum = _acpCopyWithAbsent, Object? maximum = _acpCopyWithAbsent, Object? defaultValue = _acpCopyWithAbsent, Object? meta = _acpCopyWithAbsent}) ElicitationPropertySchemaNumber
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() AcpJsonMap
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited