ElicitationSchema class final

ACP stable-v1 ElicitationSchema.

Source: /$defs/ElicitationSchema. Type-safe elicitation schema for requesting structured user input.

Annotations
  • @immutable

Constructors

ElicitationSchema({ElicitationSchemaType? type, String? title, Map<String, ElicitationPropertySchema>? properties, List<String>? requiredValue, String? description, AcpJsonMap? meta})
ElicitationSchema.fromMap(Map<Object?, Object?> value)
factory

Properties

description String?
final
hashCode int
The hash code for this object.
no setterinherited
meta AcpJsonMap?
final
properties Map<String, ElicitationPropertySchema>?
final
requiredValue List<String>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String?
final
type ElicitationSchemaType?
final

Methods

copyWith({Object? type = _acpCopyWithAbsent, Object? title = _acpCopyWithAbsent, Object? properties = _acpCopyWithAbsent, Object? requiredValue = _acpCopyWithAbsent, Object? description = _acpCopyWithAbsent, Object? meta = _acpCopyWithAbsent}) ElicitationSchema
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() AcpJsonMap
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited