ElicitationSessionScope class final

ACP stable-v1 ElicitationSessionScope.

Source: /$defs/ElicitationSessionScope. Session-scoped elicitation, optionally tied to a specific tool call.

Annotations
  • @immutable

Constructors

ElicitationSessionScope({required SessionId sessionId, ToolCallId? toolCallId})
ElicitationSessionScope.fromMap(Map<Object?, Object?> value)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionId SessionId
final
toolCallId ToolCallId?
final

Methods

copyWith({Object? sessionId = _acpCopyWithAbsent, Object? toolCallId = _acpCopyWithAbsent}) ElicitationSessionScope
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() AcpJsonMap
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited