ElicitationUrlCapabilities class final
ACP stable-v1 ElicitationUrlCapabilities.
Source: /$defs/ElicitationUrlCapabilities.
URL-based elicitation capabilities.
- Annotations
-
- @immutable
Constructors
- ElicitationUrlCapabilities({AcpJsonMap? meta})
-
ElicitationUrlCapabilities.fromMap(Map<
Object?, Object?> value) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- meta → AcpJsonMap?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{Object? meta = _acpCopyWithAbsent}) → ElicitationUrlCapabilities -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → AcpJsonMap -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited