ElicitationUrlModeSession class final

Inheritance
Annotations
  • @immutable

Constructors

ElicitationUrlModeSession({required ElicitationId elicitationId, required String url, required SessionId sessionId, ToolCallId? toolCallId})
ElicitationUrlModeSession.fromMap(Map<Object?, Object?> value)
factory

Properties

elicitationId ElicitationId
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionId SessionId
final
toolCallId ToolCallId?
final
url String
final

Methods

copyWith({Object? elicitationId = _acpCopyWithAbsent, Object? url = _acpCopyWithAbsent, Object? sessionId = _acpCopyWithAbsent, Object? toolCallId = _acpCopyWithAbsent}) ElicitationUrlModeSession
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() AcpJsonMap
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited