EmbeddedResource class final
ACP stable-v1 EmbeddedResource.
Source: /$defs/EmbeddedResource.
The contents of a resource, embedded into a prompt or tool call result.
- Annotations
-
- @immutable
Constructors
- EmbeddedResource({Annotations? annotations, required EmbeddedResourceResource resource, AcpJsonMap? meta})
-
EmbeddedResource.fromMap(Map<
Object?, Object?> value) -
factory
Properties
- annotations → Annotations?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- meta → AcpJsonMap?
-
final
- resource → EmbeddedResourceResource
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{Object? annotations = _acpCopyWithAbsent, Object? resource = _acpCopyWithAbsent, Object? meta = _acpCopyWithAbsent}) → EmbeddedResource -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → AcpJsonMap -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited