EmbeddedResourceResourceTextResourceContents class final

Inheritance
Annotations
  • @immutable

Properties

hashCode int
The hash code for this object.
no setterinherited
meta AcpJsonMap?
final
mimeType String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String
final
uri String
final

Methods

copyWith({Object? mimeType = _acpCopyWithAbsent, Object? text = _acpCopyWithAbsent, Object? uri = _acpCopyWithAbsent, Object? meta = _acpCopyWithAbsent}) EmbeddedResourceResourceTextResourceContents
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() AcpJsonMap
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited