EnumOption class final

ACP stable-v1 EnumOption.

Source: /$defs/EnumOption. A titled enum option with a const value, human-readable title, and optional description.

Annotations
  • @immutable

Constructors

EnumOption({required String constValue, required String title, String? description, AcpJsonMap? meta})
EnumOption.fromMap(Map<Object?, Object?> value)
factory

Properties

constValue String
final
description String?
final
hashCode int
The hash code for this object.
no setterinherited
meta AcpJsonMap?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String
final

Methods

copyWith({Object? constValue = _acpCopyWithAbsent, Object? title = _acpCopyWithAbsent, Object? description = _acpCopyWithAbsent, Object? meta = _acpCopyWithAbsent}) EnumOption
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() AcpJsonMap
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited