EnvVariable class final

ACP stable-v1 EnvVariable.

Source: /$defs/EnvVariable. An environment variable to set when launching an MCP server.

Annotations
  • @immutable

Constructors

EnvVariable({required String name, required String value, AcpJsonMap? meta})
EnvVariable.fromMap(Map<Object?, Object?> value)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
meta AcpJsonMap?
final
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
final

Methods

copyWith({Object? name = _acpCopyWithAbsent, Object? value = _acpCopyWithAbsent, Object? meta = _acpCopyWithAbsent}) EnvVariable
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() AcpJsonMap
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited