FileSystemCapabilities class final
ACP stable-v1 FileSystemCapabilities.
Source: /$defs/FileSystemCapabilities.
File system capabilities that a client may support.
- Annotations
-
- @immutable
Constructors
- FileSystemCapabilities({bool? readTextFile, bool? writeTextFile, AcpJsonMap? meta})
-
FileSystemCapabilities.fromMap(Map<
Object?, Object?> value) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- meta → AcpJsonMap?
-
final
- readTextFile → bool?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- writeTextFile → bool?
-
final
Methods
-
copyWith(
{Object? readTextFile = _acpCopyWithAbsent, Object? writeTextFile = _acpCopyWithAbsent, Object? meta = _acpCopyWithAbsent}) → FileSystemCapabilities -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → AcpJsonMap -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited