HttpHeader class final

ACP stable-v1 HttpHeader.

Source: /$defs/HttpHeader. An HTTP header to set when making requests to the MCP server.

Annotations
  • @immutable

Constructors

HttpHeader({required String name, required String value, AcpJsonMap? meta})
HttpHeader.fromMap(Map<Object?, Object?> value)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
meta AcpJsonMap?
final
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
final

Methods

copyWith({Object? name = _acpCopyWithAbsent, Object? value = _acpCopyWithAbsent, Object? meta = _acpCopyWithAbsent}) HttpHeader
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() AcpJsonMap
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited