Implementation class final

ACP stable-v1 Implementation.

Source: /$defs/Implementation. Metadata about the implementation of the client or agent.

Annotations
  • @immutable

Constructors

Implementation({required String name, String? title, required String version, AcpJsonMap? meta})
Implementation.fromMap(Map<Object?, Object?> value)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
meta AcpJsonMap?
final
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String?
final
version String
final

Methods

copyWith({Object? name = _acpCopyWithAbsent, Object? title = _acpCopyWithAbsent, Object? version = _acpCopyWithAbsent, Object? meta = _acpCopyWithAbsent}) Implementation
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() AcpJsonMap
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited