IntegerPropertySchema class final

ACP stable-v1 IntegerPropertySchema.

Source: /$defs/IntegerPropertySchema. Schema for integer properties in an elicitation form.

Annotations
  • @immutable

Constructors

IntegerPropertySchema({String? title, String? description, int? minimum, int? maximum, int? defaultValue, AcpJsonMap? meta})
IntegerPropertySchema.fromMap(Map<Object?, Object?> value)
factory

Properties

defaultValue int?
final
description String?
final
hashCode int
The hash code for this object.
no setterinherited
maximum int?
final
meta AcpJsonMap?
final
minimum int?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String?
final

Methods

copyWith({Object? title = _acpCopyWithAbsent, Object? description = _acpCopyWithAbsent, Object? minimum = _acpCopyWithAbsent, Object? maximum = _acpCopyWithAbsent, Object? defaultValue = _acpCopyWithAbsent, Object? meta = _acpCopyWithAbsent}) IntegerPropertySchema
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() AcpJsonMap
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited