JsonRpcErrorCodes class abstract final

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

internalError → const int
invalidParams → const int
invalidRequest → const int
methodNotFound → const int
parseError → const int
Reserved JSON-RPC parse error. A garbage stdout line has no correlatable id, so the peer never emits this code.
requestCancelled → const int