KillTerminalRequest class final

ACP stable-v1 KillTerminalRequest.

Source: /$defs/KillTerminalRequest. Request to kill a terminal without releasing it.

Annotations
  • @immutable

Constructors

KillTerminalRequest({required SessionId sessionId, required TerminalId terminalId, AcpJsonMap? meta})
KillTerminalRequest.fromMap(Map<Object?, Object?> value)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
meta AcpJsonMap?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionId SessionId
final
terminalId TerminalId
final

Methods

copyWith({Object? sessionId = _acpCopyWithAbsent, Object? terminalId = _acpCopyWithAbsent, Object? meta = _acpCopyWithAbsent}) KillTerminalRequest
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() AcpJsonMap
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited