ListSessionsRequest class final

ACP stable-v1 ListSessionsRequest.

Source: /$defs/ListSessionsRequest. Request parameters for listing existing sessions.

Annotations
  • @immutable

Constructors

ListSessionsRequest({String? cwd, String? cursor, AcpJsonMap? meta})
ListSessionsRequest.fromMap(Map<Object?, Object?> value)
factory

Properties

cursor String?
final
cwd String?
final
hashCode int
The hash code for this object.
no setterinherited
meta AcpJsonMap?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({Object? cwd = _acpCopyWithAbsent, Object? cursor = _acpCopyWithAbsent, Object? meta = _acpCopyWithAbsent}) ListSessionsRequest
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() AcpJsonMap
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited