ListSessionsResponse class final

ACP stable-v1 ListSessionsResponse.

Source: /$defs/ListSessionsResponse. Response from listing sessions.

Annotations
  • @immutable

Constructors

ListSessionsResponse({required List<SessionInfo> sessions, String? nextCursor, AcpJsonMap? meta})
ListSessionsResponse.fromMap(Map<Object?, Object?> value)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
meta AcpJsonMap?
final
nextCursor String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessions List<SessionInfo>
final

Methods

copyWith({Object? sessions = _acpCopyWithAbsent, Object? nextCursor = _acpCopyWithAbsent, Object? meta = _acpCopyWithAbsent}) ListSessionsResponse
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() AcpJsonMap
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited