McpServer class sealed
ACP stable-v1 McpServer.
Source: /$defs/McpServer.
Configuration for connecting to an MCP (Model Context Protocol) server.
- Implementers
- Annotations
-
- @immutable
Constructors
-
McpServer.fromMap(Map<
Object?, Object?> value) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Object? -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited