McpServerSse class final

ACP stable-v1 McpServerSse.

Source: /$defs/McpServerSse. SSE transport configuration for MCP.

Annotations
  • @immutable

Constructors

McpServerSse({required String name, required String url, required List<HttpHeader> headers, AcpJsonMap? meta})
McpServerSse.fromMap(Map<Object?, Object?> value)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
headers List<HttpHeader>
final
meta AcpJsonMap?
final
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
url String
final

Methods

copyWith({Object? name = _acpCopyWithAbsent, Object? url = _acpCopyWithAbsent, Object? headers = _acpCopyWithAbsent, Object? meta = _acpCopyWithAbsent}) McpServerSse
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() AcpJsonMap
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited