McpServerSseVariant class final

Inheritance
Annotations
  • @immutable

Constructors

McpServerSseVariant({required String type, required String name, required String url, required List<HttpHeader> headers, AcpJsonMap? meta})
McpServerSseVariant.fromMap(Map<Object?, Object?> value)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
headers List<HttpHeader>
final
meta AcpJsonMap?
final
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
final
url String
final

Methods

copyWith({Object? type = _acpCopyWithAbsent, Object? name = _acpCopyWithAbsent, Object? url = _acpCopyWithAbsent, Object? headers = _acpCopyWithAbsent, Object? meta = _acpCopyWithAbsent}) McpServerSseVariant
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() AcpJsonMap
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited