McpServerStdioVariant class final

Inheritance
Annotations
  • @immutable

Constructors

McpServerStdioVariant({required String name, required String command, required List<String> args, required List<EnvVariable> env, AcpJsonMap? meta})
McpServerStdioVariant.fromMap(Map<Object?, Object?> value)
factory

Properties

args List<String>
final
command String
final
env List<EnvVariable>
final
hashCode int
The hash code for this object.
no setterinherited
meta AcpJsonMap?
final
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({Object? name = _acpCopyWithAbsent, Object? command = _acpCopyWithAbsent, Object? args = _acpCopyWithAbsent, Object? env = _acpCopyWithAbsent, Object? meta = _acpCopyWithAbsent}) McpServerStdioVariant
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() AcpJsonMap
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited