MultiSelectItemsString class final

Inheritance
Annotations
  • @immutable

Constructors

MultiSelectItemsString({required String type, required List<String> enumValue, AcpJsonMap? meta})
MultiSelectItemsString.fromMap(Map<Object?, Object?> value)
factory

Properties

enumValue List<String>
final
hashCode int
The hash code for this object.
no setterinherited
meta AcpJsonMap?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
final

Methods

copyWith({Object? type = _acpCopyWithAbsent, Object? enumValue = _acpCopyWithAbsent, Object? meta = _acpCopyWithAbsent}) MultiSelectItemsString
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() AcpJsonMap
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited