MultiSelectItemsTitled class final

Inheritance
Annotations
  • @immutable

Constructors

MultiSelectItemsTitled({required List<EnumOption> anyOf, AcpJsonMap? meta})
MultiSelectItemsTitled.fromMap(Map<Object?, Object?> value)
factory

Properties

anyOf List<EnumOption>
final
hashCode int
The hash code for this object.
no setterinherited
meta AcpJsonMap?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({Object? anyOf = _acpCopyWithAbsent, Object? meta = _acpCopyWithAbsent}) MultiSelectItemsTitled
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() AcpJsonMap
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited