MultiSelectPropertySchema class final

ACP stable-v1 MultiSelectPropertySchema.

Source: /$defs/MultiSelectPropertySchema. Schema for multi-select (array) properties in an elicitation form.

Annotations
  • @immutable

Constructors

MultiSelectPropertySchema({String? title, String? description, int? minItems, int? maxItems, required MultiSelectItems items, List<String>? defaultValue, AcpJsonMap? meta})
MultiSelectPropertySchema.fromMap(Map<Object?, Object?> value)
factory

Properties

defaultValue List<String>?
final
description String?
final
hashCode int
The hash code for this object.
no setterinherited
items MultiSelectItems
final
maxItems int?
final
meta AcpJsonMap?
final
minItems int?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String?
final

Methods

copyWith({Object? title = _acpCopyWithAbsent, Object? description = _acpCopyWithAbsent, Object? minItems = _acpCopyWithAbsent, Object? maxItems = _acpCopyWithAbsent, Object? items = _acpCopyWithAbsent, Object? defaultValue = _acpCopyWithAbsent, Object? meta = _acpCopyWithAbsent}) MultiSelectPropertySchema
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() AcpJsonMap
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited