NewSessionRequest class final

ACP stable-v1 NewSessionRequest.

Source: /$defs/NewSessionRequest. Request parameters for creating a new session.

Annotations
  • @immutable

Constructors

NewSessionRequest({required String cwd, List<String>? additionalDirectories, required List<McpServer> mcpServers, AcpJsonMap? meta})
NewSessionRequest.fromMap(Map<Object?, Object?> value)
factory

Properties

additionalDirectories List<String>?
final
cwd String
final
hashCode int
The hash code for this object.
no setterinherited
mcpServers List<McpServer>
final
meta AcpJsonMap?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({Object? cwd = _acpCopyWithAbsent, Object? additionalDirectories = _acpCopyWithAbsent, Object? mcpServers = _acpCopyWithAbsent, Object? meta = _acpCopyWithAbsent}) NewSessionRequest
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() AcpJsonMap
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited