NewSessionResponse class final

ACP stable-v1 NewSessionResponse.

Source: /$defs/NewSessionResponse. Response from creating a new session.

Annotations
  • @immutable

Constructors

NewSessionResponse({required SessionId sessionId, SessionModeState? modes, List<SessionConfigOption>? configOptions, AcpJsonMap? meta})
NewSessionResponse.fromMap(Map<Object?, Object?> value)
factory

Properties

configOptions List<SessionConfigOption>?
final
hashCode int
The hash code for this object.
no setterinherited
meta AcpJsonMap?
final
modes SessionModeState?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionId SessionId
final

Methods

copyWith({Object? sessionId = _acpCopyWithAbsent, Object? modes = _acpCopyWithAbsent, Object? configOptions = _acpCopyWithAbsent, Object? meta = _acpCopyWithAbsent}) NewSessionResponse
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() AcpJsonMap
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited