PermissionOption class final

ACP stable-v1 PermissionOption.

Source: /$defs/PermissionOption. An option presented to the user when requesting permission.

Annotations
  • @immutable

Constructors

PermissionOption({required PermissionOptionId optionId, required String name, required PermissionOptionKind kind, AcpJsonMap? meta})
PermissionOption.fromMap(Map<Object?, Object?> value)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
kind PermissionOptionKind
final
meta AcpJsonMap?
final
name String
final
optionId PermissionOptionId
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({Object? optionId = _acpCopyWithAbsent, Object? name = _acpCopyWithAbsent, Object? kind = _acpCopyWithAbsent, Object? meta = _acpCopyWithAbsent}) PermissionOption
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() AcpJsonMap
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited