PermissionOptionId class final

ACP stable-v1 PermissionOptionId.

Source: /$defs/PermissionOptionId. Unique identifier for a permission option.

Annotations
  • @immutable

Constructors

PermissionOptionId(String value)
const
PermissionOptionId.fromJson(Object? value)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
final

Methods

copyWith({Object? value = _acpCopyWithAbsent}) PermissionOptionId
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object?
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited