Plan class final

ACP stable-v1 Plan.

Source: /$defs/Plan. An execution plan for accomplishing complex tasks.

Annotations
  • @immutable

Constructors

Plan({required List<PlanEntry> entries, AcpJsonMap? meta})
Plan.fromMap(Map<Object?, Object?> value)
factory

Properties

entries List<PlanEntry>
final
hashCode int
The hash code for this object.
no setterinherited
meta AcpJsonMap?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({Object? entries = _acpCopyWithAbsent, Object? meta = _acpCopyWithAbsent}) Plan
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() AcpJsonMap
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited