PlanEntry class final
ACP stable-v1 PlanEntry.
Source: /$defs/PlanEntry.
A single entry in the execution plan.
- Annotations
-
- @immutable
Constructors
- PlanEntry({required String content, required PlanEntryPriority priority, required PlanEntryStatus status, AcpJsonMap? meta})
-
PlanEntry.fromMap(Map<
Object?, Object?> value) -
factory
Properties
- content → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- meta → AcpJsonMap?
-
final
- priority → PlanEntryPriority
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → PlanEntryStatus
-
final
Methods
-
copyWith(
{Object? content = _acpCopyWithAbsent, Object? priority = _acpCopyWithAbsent, Object? status = _acpCopyWithAbsent, Object? meta = _acpCopyWithAbsent}) → PlanEntry -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → AcpJsonMap -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited