PromptRequest class final

ACP stable-v1 PromptRequest.

Source: /$defs/PromptRequest. Request parameters for sending a user prompt to the agent.

Annotations
  • @immutable

Constructors

PromptRequest({required SessionId sessionId, required List<ContentBlock> prompt, AcpJsonMap? meta})
PromptRequest.fromMap(Map<Object?, Object?> value)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
meta AcpJsonMap?
final
prompt List<ContentBlock>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionId SessionId
final

Methods

copyWith({Object? sessionId = _acpCopyWithAbsent, Object? prompt = _acpCopyWithAbsent, Object? meta = _acpCopyWithAbsent}) PromptRequest
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() AcpJsonMap
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited