PromptResponse class final

ACP stable-v1 PromptResponse.

Source: /$defs/PromptResponse. Response from processing a user prompt.

Annotations
  • @immutable

Constructors

PromptResponse({required StopReason stopReason, AcpJsonMap? meta})
PromptResponse.fromMap(Map<Object?, Object?> value)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
meta AcpJsonMap?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stopReason StopReason
final

Methods

copyWith({Object? stopReason = _acpCopyWithAbsent, Object? meta = _acpCopyWithAbsent}) PromptResponse
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() AcpJsonMap
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited