ReadTextFileRequest class final

ACP stable-v1 ReadTextFileRequest.

Source: /$defs/ReadTextFileRequest. Request to read content from a text file.

Annotations
  • @immutable

Constructors

ReadTextFileRequest({required SessionId sessionId, required String path, int? line, int? limit, AcpJsonMap? meta})
ReadTextFileRequest.fromMap(Map<Object?, Object?> value)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
limit int?
final
line int?
final
meta AcpJsonMap?
final
path String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionId SessionId
final

Methods

copyWith({Object? sessionId = _acpCopyWithAbsent, Object? path = _acpCopyWithAbsent, Object? line = _acpCopyWithAbsent, Object? limit = _acpCopyWithAbsent, Object? meta = _acpCopyWithAbsent}) ReadTextFileRequest
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() AcpJsonMap
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited