ReadTextFileResponse class final

ACP stable-v1 ReadTextFileResponse.

Source: /$defs/ReadTextFileResponse. Response containing the contents of a text file.

Annotations
  • @immutable

Constructors

ReadTextFileResponse({required String content, AcpJsonMap? meta})
ReadTextFileResponse.fromMap(Map<Object?, Object?> value)
factory

Properties

content String
final
hashCode int
The hash code for this object.
no setterinherited
meta AcpJsonMap?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({Object? content = _acpCopyWithAbsent, Object? meta = _acpCopyWithAbsent}) ReadTextFileResponse
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() AcpJsonMap
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited