RequestPermissionOutcomeSelected class final
- Inheritance
-
- Object
- RequestPermissionOutcome
- RequestPermissionOutcomeSelected
- Annotations
-
- @immutable
Constructors
- RequestPermissionOutcomeSelected({required String outcome, required PermissionOptionId optionId, AcpJsonMap? meta})
-
RequestPermissionOutcomeSelected.fromMap(Map<
Object?, Object?> value) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- meta → AcpJsonMap?
-
final
- optionId → PermissionOptionId
-
final
- outcome → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{Object? outcome = _acpCopyWithAbsent, Object? optionId = _acpCopyWithAbsent, Object? meta = _acpCopyWithAbsent}) → RequestPermissionOutcomeSelected -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → AcpJsonMap -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited