RequestPermissionRequest class final

ACP stable-v1 RequestPermissionRequest.

Source: /$defs/RequestPermissionRequest. Request for user permission to execute a tool call.

Annotations
  • @immutable

Constructors

RequestPermissionRequest({required SessionId sessionId, required ToolCallUpdate toolCall, required List<PermissionOption> options, AcpJsonMap? meta})
RequestPermissionRequest.fromMap(Map<Object?, Object?> value)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
meta AcpJsonMap?
final
options List<PermissionOption>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionId SessionId
final
toolCall ToolCallUpdate
final

Methods

copyWith({Object? sessionId = _acpCopyWithAbsent, Object? toolCall = _acpCopyWithAbsent, Object? options = _acpCopyWithAbsent, Object? meta = _acpCopyWithAbsent}) RequestPermissionRequest
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() AcpJsonMap
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited