ResumeSessionResponse class final

ACP stable-v1 ResumeSessionResponse.

Source: /$defs/ResumeSessionResponse. Response from resuming an existing session.

Annotations
  • @immutable

Constructors

ResumeSessionResponse({SessionModeState? modes, List<SessionConfigOption>? configOptions, AcpJsonMap? meta})
ResumeSessionResponse.fromMap(Map<Object?, Object?> value)
factory

Properties

configOptions List<SessionConfigOption>?
final
hashCode int
The hash code for this object.
no setterinherited
meta AcpJsonMap?
final
modes SessionModeState?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({Object? modes = _acpCopyWithAbsent, Object? configOptions = _acpCopyWithAbsent, Object? meta = _acpCopyWithAbsent}) ResumeSessionResponse
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() AcpJsonMap
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited