Role class sealed

ACP stable-v1 Role.

Source: /$defs/Role. The sender or recipient of messages and data in a conversation.

Implementers
Annotations
  • @immutable

Constructors

Role.fromJson(Object? value)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object?
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited