SessionCapabilities class final

ACP stable-v1 SessionCapabilities.

Source: /$defs/SessionCapabilities. Session capabilities supported by the agent.

Annotations
  • @immutable

Properties

additionalDirectories SessionAdditionalDirectoriesCapabilities?
final
close SessionCloseCapabilities?
final
delete SessionDeleteCapabilities?
final
hashCode int
The hash code for this object.
no setterinherited
list SessionListCapabilities?
final
meta AcpJsonMap?
final
resume SessionResumeCapabilities?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({Object? list = _acpCopyWithAbsent, Object? delete = _acpCopyWithAbsent, Object? additionalDirectories = _acpCopyWithAbsent, Object? resume = _acpCopyWithAbsent, Object? close = _acpCopyWithAbsent, Object? meta = _acpCopyWithAbsent}) SessionCapabilities
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() AcpJsonMap
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited