SessionConfigBoolean class final

ACP stable-v1 SessionConfigBoolean.

Source: /$defs/SessionConfigBoolean. A boolean on/off toggle session configuration option payload.

Annotations
  • @immutable

Constructors

SessionConfigBoolean({required bool currentValue})
SessionConfigBoolean.fromMap(Map<Object?, Object?> value)
factory

Properties

currentValue bool
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({Object? currentValue = _acpCopyWithAbsent}) SessionConfigBoolean
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() AcpJsonMap
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited