SessionConfigOptionBoolean class final

Inheritance
Annotations
  • @immutable

Constructors

SessionConfigOptionBoolean({required SessionConfigId id, required String name, String? description, SessionConfigOptionCategory? category, AcpJsonMap? meta, required String type, required bool currentValue})
SessionConfigOptionBoolean.fromMap(Map<Object?, Object?> value)
factory

Properties

category SessionConfigOptionCategory?
final
currentValue bool
final
description String?
final
hashCode int
The hash code for this object.
no setterinherited
id SessionConfigId
final
meta AcpJsonMap?
final
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
final

Methods

copyWith({Object? id = _acpCopyWithAbsent, Object? name = _acpCopyWithAbsent, Object? description = _acpCopyWithAbsent, Object? category = _acpCopyWithAbsent, Object? meta = _acpCopyWithAbsent, Object? type = _acpCopyWithAbsent, Object? currentValue = _acpCopyWithAbsent}) SessionConfigOptionBoolean
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() AcpJsonMap
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited