SessionConfigSelectGroup class final

ACP stable-v1 SessionConfigSelectGroup.

Source: /$defs/SessionConfigSelectGroup. A group of possible values for a session configuration option.

Annotations
  • @immutable

Constructors

SessionConfigSelectGroup({required SessionConfigGroupId group, required String name, required List<SessionConfigSelectOption> options, AcpJsonMap? meta})
SessionConfigSelectGroup.fromMap(Map<Object?, Object?> value)
factory

Properties

group SessionConfigGroupId
final
hashCode int
The hash code for this object.
no setterinherited
meta AcpJsonMap?
final
name String
final
options List<SessionConfigSelectOption>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({Object? group = _acpCopyWithAbsent, Object? name = _acpCopyWithAbsent, Object? options = _acpCopyWithAbsent, Object? meta = _acpCopyWithAbsent}) SessionConfigSelectGroup
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() AcpJsonMap
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited