SessionConfigSelectOption class final

ACP stable-v1 SessionConfigSelectOption.

Source: /$defs/SessionConfigSelectOption. A possible value for a session configuration option.

Annotations
  • @immutable

Constructors

SessionConfigSelectOption({required SessionConfigValueId value, required String name, String? description, AcpJsonMap? meta})
SessionConfigSelectOption.fromMap(Map<Object?, Object?> value)
factory

Properties

description String?
final
hashCode int
The hash code for this object.
no setterinherited
meta AcpJsonMap?
final
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value SessionConfigValueId
final

Methods

copyWith({Object? value = _acpCopyWithAbsent, Object? name = _acpCopyWithAbsent, Object? description = _acpCopyWithAbsent, Object? meta = _acpCopyWithAbsent}) SessionConfigSelectOption
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() AcpJsonMap
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited