SessionConfigSelectOptionsGrouped class final
- Inheritance
-
- Object
- SessionConfigSelectOptions
- SessionConfigSelectOptionsGrouped
- Annotations
-
- @immutable
Constructors
-
SessionConfigSelectOptionsGrouped(List<
SessionConfigSelectGroup> value) - SessionConfigSelectOptionsGrouped.fromJson(Object? value)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
value
→ List<
SessionConfigSelectGroup> -
final
Methods
-
copyWith(
{Object? value = _acpCopyWithAbsent}) → SessionConfigSelectOptionsGrouped -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object? -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited