SessionInfo class final

ACP stable-v1 SessionInfo.

Source: /$defs/SessionInfo. Information about a session returned by session/list

Annotations
  • @immutable

Constructors

SessionInfo({required SessionId sessionId, required String cwd, List<String>? additionalDirectories, String? title, String? updatedAt, AcpJsonMap? meta})
SessionInfo.fromMap(Map<Object?, Object?> value)
factory

Properties

additionalDirectories List<String>?
final
cwd String
final
hashCode int
The hash code for this object.
no setterinherited
meta AcpJsonMap?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionId SessionId
final
title String?
final
updatedAt String?
final

Methods

copyWith({Object? sessionId = _acpCopyWithAbsent, Object? cwd = _acpCopyWithAbsent, Object? additionalDirectories = _acpCopyWithAbsent, Object? title = _acpCopyWithAbsent, Object? updatedAt = _acpCopyWithAbsent, Object? meta = _acpCopyWithAbsent}) SessionInfo
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() AcpJsonMap
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited