SessionInfoUpdate class final

ACP stable-v1 SessionInfoUpdate.

Source: /$defs/SessionInfoUpdate. Update to session metadata. All fields are optional to support partial updates.

Annotations
  • @immutable

Constructors

SessionInfoUpdate({AcpField<String> title = const AcpField<String>.absent(), AcpField<String> updatedAt = const AcpField<String>.absent(), AcpField<AcpJsonMap> meta = const AcpField<AcpJsonMap>.absent()})
SessionInfoUpdate.fromMap(Map<Object?, Object?> value)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
meta AcpField<AcpJsonMap>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title AcpField<String>
final
updatedAt AcpField<String>
final

Methods

copyWith({Object? title = _acpCopyWithAbsent, Object? updatedAt = _acpCopyWithAbsent, Object? meta = _acpCopyWithAbsent}) SessionInfoUpdate
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() AcpJsonMap
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited