SessionListCapabilities class final
ACP stable-v1 SessionListCapabilities.
Source: /$defs/SessionListCapabilities.
Capabilities for the session/list method.
- Annotations
-
- @immutable
Constructors
- SessionListCapabilities({AcpJsonMap? meta})
-
SessionListCapabilities.fromMap(Map<
Object?, Object?> value) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- meta → AcpJsonMap?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{Object? meta = _acpCopyWithAbsent}) → SessionListCapabilities -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → AcpJsonMap -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited