SessionModeState class final
ACP stable-v1 SessionModeState.
Source: /$defs/SessionModeState.
The set of modes and the one currently active.
- Annotations
-
- @immutable
Constructors
-
SessionModeState({required SessionModeId currentModeId, required List<
SessionMode> availableModes, AcpJsonMap? meta}) -
SessionModeState.fromMap(Map<
Object?, Object?> value) -
factory
Properties
-
availableModes
→ List<
SessionMode> -
final
- currentModeId → SessionModeId
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- meta → AcpJsonMap?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{Object? currentModeId = _acpCopyWithAbsent, Object? availableModes = _acpCopyWithAbsent, Object? meta = _acpCopyWithAbsent}) → SessionModeState -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → AcpJsonMap -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited