SessionNotification class final

ACP stable-v1 SessionNotification.

Source: /$defs/SessionNotification. Notification containing a session update from the agent.

Annotations
  • @immutable

Constructors

SessionNotification({required SessionId sessionId, required SessionUpdate update, AcpJsonMap? meta})
SessionNotification.fromMap(Map<Object?, Object?> value)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
meta AcpJsonMap?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionId SessionId
final
update SessionUpdate
final

Methods

copyWith({Object? sessionId = _acpCopyWithAbsent, Object? update = _acpCopyWithAbsent, Object? meta = _acpCopyWithAbsent}) SessionNotification
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() AcpJsonMap
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited