SessionUpdateToolCall class final
- Inheritance
-
- Object
- SessionUpdate
- SessionUpdateToolCall
- Annotations
-
- @immutable
Constructors
-
SessionUpdateToolCall({required String sessionUpdate, required ToolCallId toolCallId, required String title, ToolKind? kind, ToolCallStatus? status, List<
ToolCallContent> ? content, List<ToolCallLocation> ? locations, Object? rawInput, Object? rawOutput, AcpJsonMap? meta}) -
SessionUpdateToolCall.fromMap(Map<
Object?, Object?> value) -
factory
Properties
-
content
→ List<
ToolCallContent> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- kind → ToolKind?
-
final
-
locations
→ List<
ToolCallLocation> ? -
final
- meta → AcpJsonMap?
-
final
- rawInput → Object?
-
final
- rawOutput → Object?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sessionUpdate → String
-
final
- status → ToolCallStatus?
-
final
- title → String
-
final
- toolCallId → ToolCallId
-
final
Methods
-
copyWith(
{Object? sessionUpdate = _acpCopyWithAbsent, Object? toolCallId = _acpCopyWithAbsent, Object? title = _acpCopyWithAbsent, Object? kind = _acpCopyWithAbsent, Object? status = _acpCopyWithAbsent, Object? content = _acpCopyWithAbsent, Object? locations = _acpCopyWithAbsent, Object? rawInput = _acpCopyWithAbsent, Object? rawOutput = _acpCopyWithAbsent, Object? meta = _acpCopyWithAbsent}) → SessionUpdateToolCall -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → AcpJsonMap -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited