SessionUpdateUsageUpdate class final

Inheritance
Annotations
  • @immutable

Constructors

SessionUpdateUsageUpdate({required String sessionUpdate, required int used, required int size, Cost? cost, AcpJsonMap? meta})
SessionUpdateUsageUpdate.fromMap(Map<Object?, Object?> value)
factory

Properties

cost Cost?
final
hashCode int
The hash code for this object.
no setterinherited
meta AcpJsonMap?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionUpdate String
final
size int
final
used int
final

Methods

copyWith({Object? sessionUpdate = _acpCopyWithAbsent, Object? used = _acpCopyWithAbsent, Object? size = _acpCopyWithAbsent, Object? cost = _acpCopyWithAbsent, Object? meta = _acpCopyWithAbsent}) SessionUpdateUsageUpdate
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() AcpJsonMap
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited