SessionUpdateUserMessageChunk class final
- Inheritance
-
- Object
- SessionUpdate
- SessionUpdateUserMessageChunk
- Annotations
-
- @immutable
Constructors
- SessionUpdateUserMessageChunk({required String sessionUpdate, required ContentBlock content, MessageId? messageId, AcpJsonMap? meta})
-
SessionUpdateUserMessageChunk.fromMap(Map<
Object?, Object?> value) -
factory
Properties
- content → ContentBlock
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- messageId → MessageId?
-
final
- meta → AcpJsonMap?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sessionUpdate → String
-
final
Methods
-
copyWith(
{Object? sessionUpdate = _acpCopyWithAbsent, Object? content = _acpCopyWithAbsent, Object? messageId = _acpCopyWithAbsent, Object? meta = _acpCopyWithAbsent}) → SessionUpdateUserMessageChunk -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → AcpJsonMap -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited