SetSessionConfigOptionRequestBoolean class final
- Inheritance
-
- Object
- SetSessionConfigOptionRequest
- SetSessionConfigOptionRequestBoolean
- Annotations
-
- @immutable
Constructors
- SetSessionConfigOptionRequestBoolean({required SessionId sessionId, required SessionConfigId configId, AcpJsonMap? meta, required bool value, required String type})
-
SetSessionConfigOptionRequestBoolean.fromMap(Map<
Object?, Object?> value) -
factory
Properties
- configId → SessionConfigId
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- meta → AcpJsonMap?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sessionId → SessionId
-
final
- type → String
-
final
- value → bool
-
final
Methods
-
copyWith(
{Object? sessionId = _acpCopyWithAbsent, Object? configId = _acpCopyWithAbsent, Object? meta = _acpCopyWithAbsent, Object? value = _acpCopyWithAbsent, Object? type = _acpCopyWithAbsent}) → SetSessionConfigOptionRequestBoolean -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → AcpJsonMap -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited