SetSessionConfigOptionResponse class final

ACP stable-v1 SetSessionConfigOptionResponse.

Source: /$defs/SetSessionConfigOptionResponse. Response to session/set_config_option method.

Annotations
  • @immutable

Properties

configOptions List<SessionConfigOption>
final
hashCode int
The hash code for this object.
no setterinherited
meta AcpJsonMap?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({Object? configOptions = _acpCopyWithAbsent, Object? meta = _acpCopyWithAbsent}) SetSessionConfigOptionResponse
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() AcpJsonMap
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited