SetSessionModeRequest class final

ACP stable-v1 SetSessionModeRequest.

Source: /$defs/SetSessionModeRequest. Request parameters for setting a session mode.

Annotations
  • @immutable

Constructors

SetSessionModeRequest({required SessionId sessionId, required SessionModeId modeId, AcpJsonMap? meta})
SetSessionModeRequest.fromMap(Map<Object?, Object?> value)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
meta AcpJsonMap?
final
modeId SessionModeId
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionId SessionId
final

Methods

copyWith({Object? sessionId = _acpCopyWithAbsent, Object? modeId = _acpCopyWithAbsent, Object? meta = _acpCopyWithAbsent}) SetSessionModeRequest
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() AcpJsonMap
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited