SetSessionModeResponse class final

ACP stable-v1 SetSessionModeResponse.

Source: /$defs/SetSessionModeResponse. Response to session/set_mode method.

Annotations
  • @immutable

Properties

hashCode int
The hash code for this object.
no setterinherited
meta AcpJsonMap?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({Object? meta = _acpCopyWithAbsent}) SetSessionModeResponse
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() AcpJsonMap
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited