StdioAcpTransport class final

Implemented types

Properties

closed Future<void>
no setteroverride
diagnostics Stream<String>
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
messages Stream<Object?>
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() Future<void>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
send(Object? message) Future<void>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

launch({required AgentLaunchCommand command, required ProcessExecutor executor, Duration terminationTimeout = const Duration(seconds: 5)}) Future<StdioAcpTransport>