StopReason class sealed

ACP stable-v1 StopReason.

Source: /$defs/StopReason. Reasons why an agent stops processing a prompt turn.

Implementers
Annotations
  • @immutable

Constructors

StopReason.fromJson(Object? value)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object?
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited