StringMultiSelectItems class final

ACP stable-v1 StringMultiSelectItems.

Source: /$defs/StringMultiSelectItems. String item schema for multi-select enum properties.

Annotations
  • @immutable

Constructors

StringMultiSelectItems({required List<String> enumValue, AcpJsonMap? meta})
StringMultiSelectItems.fromMap(Map<Object?, Object?> value)
factory

Properties

enumValue List<String>
final
hashCode int
The hash code for this object.
no setterinherited
meta AcpJsonMap?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({Object? enumValue = _acpCopyWithAbsent, Object? meta = _acpCopyWithAbsent}) StringMultiSelectItems
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() AcpJsonMap
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited