Terminal class final

ACP stable-v1 Terminal.

Source: /$defs/Terminal. Embed a terminal created with terminal/create by its id.

Annotations
  • @immutable

Constructors

Terminal({required TerminalId terminalId, AcpJsonMap? meta})
Terminal.fromMap(Map<Object?, Object?> value)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
meta AcpJsonMap?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
terminalId TerminalId
final

Methods

copyWith({Object? terminalId = _acpCopyWithAbsent, Object? meta = _acpCopyWithAbsent}) Terminal
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() AcpJsonMap
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited