TerminalId class final

ACP stable-v1 TerminalId.

Source: /$defs/TerminalId. Typed identifier used for terminal values on the wire.

Annotations
  • @immutable

Constructors

TerminalId(String value)
const
TerminalId.fromJson(Object? value)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
final

Methods

copyWith({Object? value = _acpCopyWithAbsent}) TerminalId
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object?
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited