TerminalOutputResponse class final

ACP stable-v1 TerminalOutputResponse.

Source: /$defs/TerminalOutputResponse. Response containing the terminal output and exit status.

Annotations
  • @immutable

Constructors

TerminalOutputResponse({required String output, required bool truncated, TerminalExitStatus? exitStatus, AcpJsonMap? meta})
TerminalOutputResponse.fromMap(Map<Object?, Object?> value)
factory

Properties

exitStatus TerminalExitStatus?
final
hashCode int
The hash code for this object.
no setterinherited
meta AcpJsonMap?
final
output String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
truncated bool
final

Methods

copyWith({Object? output = _acpCopyWithAbsent, Object? truncated = _acpCopyWithAbsent, Object? exitStatus = _acpCopyWithAbsent, Object? meta = _acpCopyWithAbsent}) TerminalOutputResponse
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() AcpJsonMap
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited