TextContent class final

ACP stable-v1 TextContent.

Source: /$defs/TextContent. Text provided to or from an LLM.

Annotations
  • @immutable

Constructors

TextContent({Annotations? annotations, required String text, AcpJsonMap? meta})
TextContent.fromMap(Map<Object?, Object?> value)
factory

Properties

annotations Annotations?
final
hashCode int
The hash code for this object.
no setterinherited
meta AcpJsonMap?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String
final

Methods

copyWith({Object? annotations = _acpCopyWithAbsent, Object? text = _acpCopyWithAbsent, Object? meta = _acpCopyWithAbsent}) TextContent
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() AcpJsonMap
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited