TextResourceContents class final

ACP stable-v1 TextResourceContents.

Source: /$defs/TextResourceContents. Text-based resource contents.

Annotations
  • @immutable

Constructors

TextResourceContents({String? mimeType, required String text, required String uri, AcpJsonMap? meta})
TextResourceContents.fromMap(Map<Object?, Object?> value)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
meta AcpJsonMap?
final
mimeType String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String
final
uri String
final

Methods

copyWith({Object? mimeType = _acpCopyWithAbsent, Object? text = _acpCopyWithAbsent, Object? uri = _acpCopyWithAbsent, Object? meta = _acpCopyWithAbsent}) TextResourceContents
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() AcpJsonMap
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited