ToolCallContentContent class final

Inheritance
Annotations
  • @immutable

Constructors

ToolCallContentContent({required String type, required ContentBlock content, AcpJsonMap? meta})
ToolCallContentContent.fromMap(Map<Object?, Object?> value)
factory

Properties

content ContentBlock
final
hashCode int
The hash code for this object.
no setterinherited
meta AcpJsonMap?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
final

Methods

copyWith({Object? type = _acpCopyWithAbsent, Object? content = _acpCopyWithAbsent, Object? meta = _acpCopyWithAbsent}) ToolCallContentContent
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() AcpJsonMap
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited