ToolCallId class final

ACP stable-v1 ToolCallId.

Source: /$defs/ToolCallId. Unique identifier for a tool call within a session.

Annotations
  • @immutable

Constructors

ToolCallId(String value)
const
ToolCallId.fromJson(Object? value)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
final

Methods

copyWith({Object? value = _acpCopyWithAbsent}) ToolCallId
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object?
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited