ToolCallLocation class final

ACP stable-v1 ToolCallLocation.

Source: /$defs/ToolCallLocation. A file location being accessed or modified by a tool.

Annotations
  • @immutable

Constructors

ToolCallLocation({required String path, int? line, AcpJsonMap? meta})
ToolCallLocation.fromMap(Map<Object?, Object?> value)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
line int?
final
meta AcpJsonMap?
final
path String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({Object? path = _acpCopyWithAbsent, Object? line = _acpCopyWithAbsent, Object? meta = _acpCopyWithAbsent}) ToolCallLocation
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() AcpJsonMap
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited