ToolCallStatusCompleted class final

Inheritance
Annotations
  • @immutable

Constructors

ToolCallStatusCompleted()
const
ToolCallStatusCompleted.fromJson(Object? value)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith() ToolCallStatusCompleted
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object?
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited