UsageUpdate class final

ACP stable-v1 UsageUpdate.

Source: /$defs/UsageUpdate. Context window and cost update for a session.

Annotations
  • @immutable

Constructors

UsageUpdate({required int used, required int size, Cost? cost, AcpJsonMap? meta})
UsageUpdate.fromMap(Map<Object?, Object?> value)
factory

Properties

cost Cost?
final
hashCode int
The hash code for this object.
no setterinherited
meta AcpJsonMap?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size int
final
used int
final

Methods

copyWith({Object? used = _acpCopyWithAbsent, Object? size = _acpCopyWithAbsent, Object? cost = _acpCopyWithAbsent, Object? meta = _acpCopyWithAbsent}) UsageUpdate
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() AcpJsonMap
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited