WaitForTerminalExitResponse class final

ACP stable-v1 WaitForTerminalExitResponse.

Source: /$defs/WaitForTerminalExitResponse. Response containing the exit status of a terminal command.

Annotations
  • @immutable

Constructors

WaitForTerminalExitResponse({int? exitCode, String? signal, AcpJsonMap? meta})
WaitForTerminalExitResponse.fromMap(Map<Object?, Object?> value)
factory

Properties

exitCode int?
final
hashCode int
The hash code for this object.
no setterinherited
meta AcpJsonMap?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
signal String?
final

Methods

copyWith({Object? exitCode = _acpCopyWithAbsent, Object? signal = _acpCopyWithAbsent, Object? meta = _acpCopyWithAbsent}) WaitForTerminalExitResponse
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() AcpJsonMap
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited