AgentSession class abstract interface

A long-lived Agent conversation.

Properties

closed Future<void>
no setter
configOptions List<AgentConfigOption>
no setter
hashCode int
The hash code for this object.
no setterinherited
id AgentSessionId
no setter
isOpen bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
snapshot AgentSessionSnapshot
no setter
snapshots Stream<AgentSessionSnapshot>
no setter
updates Stream<AgentUpdate>
no setter

Methods

cancelActiveWork() Future<void>
close() Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setConfigOption(AgentConfigOptionSelection selection) Future<List<AgentConfigOption>>
startPrompt(AgentPrompt prompt) AgentTurn
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited