AgentSessionPage class final

Annotations
  • @immutable

Constructors

AgentSessionPage({required List<AgentSessionInfo> sessions, String? nextCursor})

Properties

hashCode int
The hash code for this object.
no setterinherited
nextCursor String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessions List<AgentSessionInfo>
final

Methods

copyWith({List<AgentSessionInfo>? sessions, String? nextCursor}) AgentSessionPage
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited