ShellProcessExecutor class

Production ProcessExecutor backed by Process.start.

Implemented types

Constructors

ShellProcessExecutor({ProcessLogSink? logger, bool includeParentEnvironment = true, Duration timeoutGracePeriod = const Duration(seconds: 2), Duration killGracePeriod = const Duration(seconds: 2), Duration timedOutOutputDrainTimeout = const Duration(seconds: 1)})

Properties

hashCode int
The hash code for this object.
no setterinherited
includeParentEnvironment bool
When false, Process.start does not merge the host environment.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
run(String executable, List<String> arguments, {String? workingDirectory, Map<String, String>? environment, Duration? timeout}) Future<ExecutionResult>
override
startBidirectional(String executable, List<String> arguments, {String? workingDirectory, Map<String, String>? environment}) Future<BidirectionalProcess>
Start a long-lived bidirectional process where stdin remains open.
override
startStreaming(String executable, List<String> arguments, {String? workingDirectory, Map<String, String>? environment}) Future<StreamingProcess>
override
toString() String
A string representation of this object.
inherited
withoutParentEnvironment() ShellProcessExecutor

Operators

operator ==(Object other) bool
The equality operator.
inherited