ProviderBinaryResolution class final

Annotations
  • @immutable

Constructors

ProviderBinaryResolution({required String path, required String version})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
path String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
version String
final

Methods

copyWith({String? path, String? version}) ProviderBinaryResolution
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited