AcpFieldValue<T extends Object> class
final
An AcpField that was present with a non-null value.
Properties
-
hashCode
→ int
-
The hash code for this object.
no setteroverride
-
hasValue
→ bool
-
Whether this field has a non-null value.
no setterinherited
-
isAbsent
→ bool
-
Whether this field was absent on the wire.
no setterinherited
-
isNull
→ bool
-
Whether this field was explicitly
null on the wire.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
value
→ T
-
final
-
valueOrNull
→ T?
-
The non-null value, or
null when the field is absent or explicitly null.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
override