Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
create(
CreateTerminalRequest request) → Future< CreateTerminalResponse> -
kill(
KillTerminalRequest request) → Future< KillTerminalResponse> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
output(
TerminalOutputRequest request) → Future< TerminalOutputResponse> -
release(
ReleaseTerminalRequest request) → Future< ReleaseTerminalResponse> -
toString(
) → String -
A string representation of this object.
inherited
-
waitForExit(
WaitForTerminalExitRequest request) → Future< WaitForTerminalExitResponse>
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited