AcpV1NotificationRoute<Parameters extends Object> class
final
- Inheritance
-
- Object
- AcpV1Route
- AcpV1NotificationRoute
- Annotations
-
- @immutable
Constructors
- AcpV1NotificationRoute({required String method, required String symbol, required AcpV1MethodOwner owner, required String parametersDefinition, required Parameters decodeParameters(Object? value), required Object? encodeParameters(Parameters value)})
-
const
Properties
- decodeParameters → Parameters Function(Object? value)
-
final
- encodeParameters → Object? Function(Parameters value)
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- method → String
-
finalinherited
- owner → AcpV1MethodOwner
-
finalinherited
- parametersDefinition → String
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- symbol → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited