AudioContent class final
ACP stable-v1 AudioContent.
Source: /$defs/AudioContent.
Audio provided to or from an LLM.
- Annotations
-
- @immutable
Constructors
- AudioContent({Annotations? annotations, required String data, required String mimeType, AcpJsonMap? meta})
-
AudioContent.fromMap(Map<
Object?, Object?> value) -
factory
Properties
- annotations → Annotations?
-
final
- data → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- meta → AcpJsonMap?
-
final
- mimeType → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{Object? annotations = _acpCopyWithAbsent, Object? data = _acpCopyWithAbsent, Object? mimeType = _acpCopyWithAbsent, Object? meta = _acpCopyWithAbsent}) → AudioContent -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → AcpJsonMap -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited