AuthMethodAgentVariant class final
- Inheritance
-
- Object
- AuthMethod
- AuthMethodAgentVariant
- Annotations
-
- @immutable
Constructors
- AuthMethodAgentVariant({required AuthMethodId id, required String name, String? description, AcpJsonMap? meta})
-
AuthMethodAgentVariant.fromMap(Map<
Object?, Object?> value) -
factory
Properties
- description → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → AuthMethodId
-
final
- meta → AcpJsonMap?
-
final
- name → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{Object? id = _acpCopyWithAbsent, Object? name = _acpCopyWithAbsent, Object? description = _acpCopyWithAbsent, Object? meta = _acpCopyWithAbsent}) → AuthMethodAgentVariant -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → AcpJsonMap -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited