AvailableCommand class final
ACP stable-v1 AvailableCommand.
Source: /$defs/AvailableCommand.
Information about a command.
- Annotations
-
- @immutable
Constructors
- AvailableCommand({required String name, required String description, AvailableCommandInput? input, AcpJsonMap? meta})
-
AvailableCommand.fromMap(Map<
Object?, Object?> value) -
factory
Properties
- description → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- input → AvailableCommandInput?
-
final
- meta → AcpJsonMap?
-
final
- name → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{Object? name = _acpCopyWithAbsent, Object? description = _acpCopyWithAbsent, Object? input = _acpCopyWithAbsent, Object? meta = _acpCopyWithAbsent}) → AvailableCommand -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → AcpJsonMap -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited