AvailableCommandInputUnstructured class final

Inheritance
Annotations
  • @immutable

Properties

hashCode int
The hash code for this object.
no setterinherited
hint String
final
meta AcpJsonMap?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({Object? hint = _acpCopyWithAbsent, Object? meta = _acpCopyWithAbsent}) AvailableCommandInputUnstructured
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() AcpJsonMap
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited