BooleanPropertySchema class final
ACP stable-v1 BooleanPropertySchema.
Source: /$defs/BooleanPropertySchema.
Schema for boolean properties in an elicitation form.
- Annotations
-
- @immutable
Constructors
- BooleanPropertySchema({String? title, String? description, bool? defaultValue, AcpJsonMap? meta})
-
BooleanPropertySchema.fromMap(Map<
Object?, Object?> value) -
factory
Properties
- defaultValue → bool?
-
final
- description → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- meta → AcpJsonMap?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- title → String?
-
final
Methods
-
copyWith(
{Object? title = _acpCopyWithAbsent, Object? description = _acpCopyWithAbsent, Object? defaultValue = _acpCopyWithAbsent, Object? meta = _acpCopyWithAbsent}) → BooleanPropertySchema -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → AcpJsonMap -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited