ClientCapabilities class final
ACP stable-v1 ClientCapabilities.
Source: /$defs/ClientCapabilities.
Capabilities supported by the client.
- Annotations
-
- @immutable
Constructors
- ClientCapabilities({FileSystemCapabilities? fs, bool? terminal, ClientSessionCapabilities? session, ElicitationCapabilities? elicitation, AcpJsonMap? meta})
-
ClientCapabilities.fromMap(Map<
Object?, Object?> value) -
factory
Properties
- elicitation → ElicitationCapabilities?
-
final
- fs → FileSystemCapabilities?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- meta → AcpJsonMap?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- session → ClientSessionCapabilities?
-
final
- terminal → bool?
-
final
Methods
-
copyWith(
{Object? fs = _acpCopyWithAbsent, Object? terminal = _acpCopyWithAbsent, Object? session = _acpCopyWithAbsent, Object? elicitation = _acpCopyWithAbsent, Object? meta = _acpCopyWithAbsent}) → ClientCapabilities -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → AcpJsonMap -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited