ContentBlockAudio class final

Inheritance
Annotations
  • @immutable

Constructors

ContentBlockAudio({required String type, Annotations? annotations, required String data, required String mimeType, AcpJsonMap? meta})
ContentBlockAudio.fromMap(Map<Object?, Object?> value)
factory

Properties

annotations Annotations?
final
data String
final
hashCode int
The hash code for this object.
no setterinherited
meta AcpJsonMap?
final
mimeType String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
final

Methods

copyWith({Object? type = _acpCopyWithAbsent, Object? annotations = _acpCopyWithAbsent, Object? data = _acpCopyWithAbsent, Object? mimeType = _acpCopyWithAbsent, Object? meta = _acpCopyWithAbsent}) ContentBlockAudio
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() AcpJsonMap
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited