ContentBlockResourceLink class final
- Inheritance
-
- Object
- ContentBlock
- ContentBlockResourceLink
- Annotations
-
- @immutable
Constructors
- ContentBlockResourceLink({required String type, Annotations? annotations, String? description, String? mimeType, required String name, int? size, String? title, required String uri, AcpJsonMap? meta})
-
ContentBlockResourceLink.fromMap(Map<
Object?, Object?> value) -
factory
Properties
- annotations → Annotations?
-
final
- description → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- meta → AcpJsonMap?
-
final
- mimeType → String?
-
final
- name → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- size → int?
-
final
- title → String?
-
final
- type → String
-
final
- uri → String
-
final
Methods
-
copyWith(
{Object? type = _acpCopyWithAbsent, Object? annotations = _acpCopyWithAbsent, Object? description = _acpCopyWithAbsent, Object? mimeType = _acpCopyWithAbsent, Object? name = _acpCopyWithAbsent, Object? size = _acpCopyWithAbsent, Object? title = _acpCopyWithAbsent, Object? uri = _acpCopyWithAbsent, Object? meta = _acpCopyWithAbsent}) → ContentBlockResourceLink -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → AcpJsonMap -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited