CreateElicitationRequestUrl class final
- Inheritance
-
- Object
- CreateElicitationRequest
- CreateElicitationRequestUrl
- Annotations
-
- @immutable
Constructors
- CreateElicitationRequestUrl({required String message, AcpJsonMap? meta, required String mode, required ElicitationId elicitationId, required String url, SessionId? sessionId, ToolCallId? toolCallId, RequestId? requestId})
-
CreateElicitationRequestUrl.fromMap(Map<
Object?, Object?> value) -
factory
Properties
- elicitationId → ElicitationId
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String
-
final
- meta → AcpJsonMap?
-
final
- mode → String
-
final
- requestId → RequestId?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sessionId → SessionId?
-
final
- toolCallId → ToolCallId?
-
final
- url → String
-
final
Methods
-
copyWith(
{Object? message = _acpCopyWithAbsent, Object? meta = _acpCopyWithAbsent, Object? mode = _acpCopyWithAbsent, Object? elicitationId = _acpCopyWithAbsent, Object? url = _acpCopyWithAbsent, Object? sessionId = _acpCopyWithAbsent, Object? toolCallId = _acpCopyWithAbsent, Object? requestId = _acpCopyWithAbsent}) → CreateElicitationRequestUrl -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → AcpJsonMap -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited