CreateElicitationResponseDecline class final
- Inheritance
-
- Object
- CreateElicitationResponse
- CreateElicitationResponseDecline
- Annotations
-
- @immutable
Constructors
- CreateElicitationResponseDecline({AcpJsonMap? meta, required String action})
-
CreateElicitationResponseDecline.fromMap(Map<
Object?, Object?> value) -
factory
Properties
- action → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- meta → AcpJsonMap?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{Object? meta = _acpCopyWithAbsent, Object? action = _acpCopyWithAbsent}) → CreateElicitationResponseDecline -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → AcpJsonMap -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited