ElicitationUrlMode class sealed
ACP stable-v1 ElicitationUrlMode.
Source: /$defs/ElicitationUrlMode.
URL-based elicitation mode where the client directs the user to a URL.
- Implementers
- Annotations
-
- @immutable
Constructors
-
ElicitationUrlMode.fromMap(Map<
Object?, Object?> value) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Object? -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited