ExtRequest class final

ACP stable-v1 ExtRequest.

Source: /$defs/ExtRequest. Allows for sending an arbitrary request that is not part of the ACP spec.

Annotations
  • @immutable

Constructors

ExtRequest(Object? value)
ExtRequest.fromJson(Object? value)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value Object?
final

Methods

copyWith({Object? value = _acpCopyWithAbsent}) ExtRequest
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object?
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited