InitializeRequest class final
ACP stable-v1 InitializeRequest.
Source: /$defs/InitializeRequest.
Request parameters for the initialize method.
- Annotations
-
- @immutable
Constructors
- InitializeRequest({required ProtocolVersion protocolVersion, ClientCapabilities? clientCapabilities, Implementation? clientInfo, AcpJsonMap? meta})
-
InitializeRequest.fromMap(Map<
Object?, Object?> value) -
factory
Properties
- clientCapabilities → ClientCapabilities?
-
final
- clientInfo → Implementation?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- meta → AcpJsonMap?
-
final
- protocolVersion → ProtocolVersion
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{Object? protocolVersion = _acpCopyWithAbsent, Object? clientCapabilities = _acpCopyWithAbsent, Object? clientInfo = _acpCopyWithAbsent, Object? meta = _acpCopyWithAbsent}) → InitializeRequest -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → AcpJsonMap -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited