InitializeResponse class final
ACP stable-v1 InitializeResponse.
Source: /$defs/InitializeResponse.
Response to the initialize method.
- Annotations
-
- @immutable
Constructors
-
InitializeResponse({required ProtocolVersion protocolVersion, AgentCapabilities? agentCapabilities, List<
AuthMethod> ? authMethods, Implementation? agentInfo, AcpJsonMap? meta}) -
InitializeResponse.fromMap(Map<
Object?, Object?> value) -
factory
Properties
- agentCapabilities → AgentCapabilities?
-
final
- agentInfo → Implementation?
-
final
-
authMethods
→ List<
AuthMethod> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- meta → AcpJsonMap?
-
final
- protocolVersion → ProtocolVersion
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{Object? protocolVersion = _acpCopyWithAbsent, Object? agentCapabilities = _acpCopyWithAbsent, Object? authMethods = _acpCopyWithAbsent, Object? agentInfo = _acpCopyWithAbsent, Object? meta = _acpCopyWithAbsent}) → InitializeResponse -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → AcpJsonMap -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited