McpCapabilities class final
ACP stable-v1 McpCapabilities.
Source: /$defs/McpCapabilities.
MCP capabilities supported by the agent
- Annotations
-
- @immutable
Constructors
- McpCapabilities({bool? http, bool? sse, AcpJsonMap? meta})
-
McpCapabilities.fromMap(Map<
Object?, Object?> value) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- http → bool?
-
final
- meta → AcpJsonMap?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sse → bool?
-
final
Methods
-
copyWith(
{Object? http = _acpCopyWithAbsent, Object? sse = _acpCopyWithAbsent, Object? meta = _acpCopyWithAbsent}) → McpCapabilities -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → AcpJsonMap -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited