PromptCapabilities class final
ACP stable-v1 PromptCapabilities.
Source: /$defs/PromptCapabilities.
Prompt capabilities supported by the agent in session/prompt requests.
- Annotations
-
- @immutable
Constructors
- PromptCapabilities({bool? image, bool? audio, bool? embeddedContext, AcpJsonMap? meta})
-
PromptCapabilities.fromMap(Map<
Object?, Object?> value) -
factory
Properties
- audio → bool?
-
final
- embeddedContext → bool?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- image → bool?
-
final
- meta → AcpJsonMap?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{Object? image = _acpCopyWithAbsent, Object? audio = _acpCopyWithAbsent, Object? embeddedContext = _acpCopyWithAbsent, Object? meta = _acpCopyWithAbsent}) → PromptCapabilities -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → AcpJsonMap -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited