ResourceLink class final
ACP stable-v1 ResourceLink.
Source: /$defs/ResourceLink.
A resource that the server is capable of reading, included in a prompt or tool call result.
- Annotations
-
- @immutable
Constructors
- ResourceLink({Annotations? annotations, String? description, String? mimeType, required String name, int? size, String? title, required String uri, AcpJsonMap? meta})
-
ResourceLink.fromMap(Map<
Object?, Object?> value) -
factory
Properties
- annotations → Annotations?
-
final
- description → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- meta → AcpJsonMap?
-
final
- mimeType → String?
-
final
- name → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- size → int?
-
final
- title → String?
-
final
- uri → String
-
final
Methods
-
copyWith(
{Object? annotations = _acpCopyWithAbsent, Object? description = _acpCopyWithAbsent, Object? mimeType = _acpCopyWithAbsent, Object? name = _acpCopyWithAbsent, Object? size = _acpCopyWithAbsent, Object? title = _acpCopyWithAbsent, Object? uri = _acpCopyWithAbsent, Object? meta = _acpCopyWithAbsent}) → ResourceLink -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → AcpJsonMap -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited