ResumeSessionRequest class final
ACP stable-v1 ResumeSessionRequest.
Source: /$defs/ResumeSessionRequest.
Request parameters for resuming an existing session.
- Annotations
-
- @immutable
Constructors
-
ResumeSessionRequest({required SessionId sessionId, required String cwd, List<
String> ? additionalDirectories, List<McpServer> ? mcpServers, AcpJsonMap? meta}) -
ResumeSessionRequest.fromMap(Map<
Object?, Object?> value) -
factory
Properties
-
additionalDirectories
→ List<
String> ? -
final
- cwd → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
mcpServers
→ List<
McpServer> ? -
final
- meta → AcpJsonMap?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sessionId → SessionId
-
final
Methods
-
copyWith(
{Object? sessionId = _acpCopyWithAbsent, Object? cwd = _acpCopyWithAbsent, Object? additionalDirectories = _acpCopyWithAbsent, Object? mcpServers = _acpCopyWithAbsent, Object? meta = _acpCopyWithAbsent}) → ResumeSessionRequest -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → AcpJsonMap -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited