SelectedPermissionOutcome class final
ACP stable-v1 SelectedPermissionOutcome.
Source: /$defs/SelectedPermissionOutcome.
The user selected one of the provided options.
- Annotations
-
- @immutable
Constructors
- SelectedPermissionOutcome({required PermissionOptionId optionId, AcpJsonMap? meta})
-
SelectedPermissionOutcome.fromMap(Map<
Object?, Object?> value) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- meta → AcpJsonMap?
-
final
- optionId → PermissionOptionId
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{Object? optionId = _acpCopyWithAbsent, Object? meta = _acpCopyWithAbsent}) → SelectedPermissionOutcome -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → AcpJsonMap -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited