SessionConfigGroupId class final
ACP stable-v1 SessionConfigGroupId.
Source: /$defs/SessionConfigGroupId.
Unique identifier for a session configuration option value group.
- Annotations
-
- @immutable
Constructors
- SessionConfigGroupId(String value)
-
const
- SessionConfigGroupId.fromJson(Object? value)
-
factory
Properties
Methods
-
copyWith(
{Object? value = _acpCopyWithAbsent}) → SessionConfigGroupId -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object? -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited