SessionConfigSelect class final
ACP stable-v1 SessionConfigSelect.
Source: /$defs/SessionConfigSelect.
A single-value selector (dropdown) session configuration option payload.
- Annotations
-
- @immutable
Constructors
- SessionConfigSelect({required SessionConfigValueId currentValue, required SessionConfigSelectOptions options})
-
SessionConfigSelect.fromMap(Map<
Object?, Object?> value) -
factory
Properties
- currentValue → SessionConfigValueId
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- options → SessionConfigSelectOptions
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{Object? currentValue = _acpCopyWithAbsent, Object? options = _acpCopyWithAbsent}) → SessionConfigSelect -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → AcpJsonMap -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited