SessionUpdateAvailableCommandsUpdate class final
- Inheritance
-
- Object
- SessionUpdate
- SessionUpdateAvailableCommandsUpdate
- Annotations
-
- @immutable
Constructors
-
SessionUpdateAvailableCommandsUpdate({required String sessionUpdate, required List<
AvailableCommand> availableCommands, AcpJsonMap? meta}) -
SessionUpdateAvailableCommandsUpdate.fromMap(Map<
Object?, Object?> value) -
factory
Properties
-
availableCommands
→ List<
AvailableCommand> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- meta → AcpJsonMap?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sessionUpdate → String
-
final
Methods
-
copyWith(
{Object? sessionUpdate = _acpCopyWithAbsent, Object? availableCommands = _acpCopyWithAbsent, Object? meta = _acpCopyWithAbsent}) → SessionUpdateAvailableCommandsUpdate -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → AcpJsonMap -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited