SessionUpdateSessionInfoUpdate class final
- Inheritance
-
- Object
- SessionUpdate
- SessionUpdateSessionInfoUpdate
- Annotations
-
- @immutable
Constructors
-
SessionUpdateSessionInfoUpdate({required String sessionUpdate, AcpField<
String> title = const AcpField<String>.absent(), AcpField<String> updatedAt = const AcpField<String>.absent(), AcpField<AcpJsonMap> meta = const AcpField<AcpJsonMap>.absent()}) -
SessionUpdateSessionInfoUpdate.fromMap(Map<
Object?, Object?> value) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
meta
→ AcpField<
AcpJsonMap> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sessionUpdate → String
-
final
-
title
→ AcpField<
String> -
final
-
updatedAt
→ AcpField<
String> -
final
Methods
-
copyWith(
{Object? sessionUpdate = _acpCopyWithAbsent, Object? title = _acpCopyWithAbsent, Object? updatedAt = _acpCopyWithAbsent, Object? meta = _acpCopyWithAbsent}) → SessionUpdateSessionInfoUpdate -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → AcpJsonMap -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited