StringPropertySchema class final
ACP stable-v1 StringPropertySchema.
Source: /$defs/StringPropertySchema.
Schema for string properties in an elicitation form.
- Annotations
-
- @immutable
Constructors
-
StringPropertySchema({String? title, String? description, int? minLength, int? maxLength, String? pattern, StringFormat? format, String? defaultValue, List<
String> ? enumValue, List<EnumOption> ? oneOf, AcpJsonMap? meta}) -
StringPropertySchema.fromMap(Map<
Object?, Object?> value) -
factory
Properties
- defaultValue → String?
-
final
- description → String?
-
final
-
enumValue
→ List<
String> ? -
final
- format → StringFormat?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxLength → int?
-
final
- meta → AcpJsonMap?
-
final
- minLength → int?
-
final
-
oneOf
→ List<
EnumOption> ? -
final
- pattern → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- title → String?
-
final
Methods
-
copyWith(
{Object? title = _acpCopyWithAbsent, Object? description = _acpCopyWithAbsent, Object? minLength = _acpCopyWithAbsent, Object? maxLength = _acpCopyWithAbsent, Object? pattern = _acpCopyWithAbsent, Object? format = _acpCopyWithAbsent, Object? defaultValue = _acpCopyWithAbsent, Object? enumValue = _acpCopyWithAbsent, Object? oneOf = _acpCopyWithAbsent, Object? meta = _acpCopyWithAbsent}) → StringPropertySchema -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → AcpJsonMap -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited