TerminalOutputRequest class final
ACP stable-v1 TerminalOutputRequest.
Source: /$defs/TerminalOutputRequest.
Request to get the current output and status of a terminal.
- Annotations
-
- @immutable
Constructors
- TerminalOutputRequest({required SessionId sessionId, required TerminalId terminalId, AcpJsonMap? meta})
-
TerminalOutputRequest.fromMap(Map<
Object?, Object?> value) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- meta → AcpJsonMap?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sessionId → SessionId
-
final
- terminalId → TerminalId
-
final
Methods
-
copyWith(
{Object? sessionId = _acpCopyWithAbsent, Object? terminalId = _acpCopyWithAbsent, Object? meta = _acpCopyWithAbsent}) → TerminalOutputRequest -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → AcpJsonMap -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited