ToolCallContentTerminal class final
- Inheritance
-
- Object
- ToolCallContent
- ToolCallContentTerminal
- Annotations
-
- @immutable
Constructors
- ToolCallContentTerminal({required String type, required TerminalId terminalId, AcpJsonMap? meta})
-
ToolCallContentTerminal.fromMap(Map<
Object?, Object?> value) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- meta → AcpJsonMap?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- terminalId → TerminalId
-
final
- type → String
-
final
Methods
-
copyWith(
{Object? type = _acpCopyWithAbsent, Object? terminalId = _acpCopyWithAbsent, Object? meta = _acpCopyWithAbsent}) → ToolCallContentTerminal -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → AcpJsonMap -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited