UnstructuredCommandInput class final
ACP stable-v1 UnstructuredCommandInput.
Source: /$defs/UnstructuredCommandInput.
All text that was typed after the command name is provided as input.
- Annotations
-
- @immutable
Constructors
- UnstructuredCommandInput({required String hint, AcpJsonMap? meta})
-
UnstructuredCommandInput.fromMap(Map<
Object?, Object?> value) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- hint → String
-
final
- meta → AcpJsonMap?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{Object? hint = _acpCopyWithAbsent, Object? meta = _acpCopyWithAbsent}) → UnstructuredCommandInput -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → AcpJsonMap -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited