menu
agent_harness package
documentation
agent_harness.dart
AgentInfo class
AgentInfo class
dark_mode
light_mode
AgentInfo
class
final
Annotations
@immutable
Constructors
AgentInfo
({
required
String
name
,
required
String
version
,
String
?
title
})
const
AgentInfo.fromMap
(
Map
<
String
,
Object
?
>
map
)
factory
Properties
hashCode
→
int
The hash code for this object.
no setter
inherited
name
→
String
final
runtimeType
→
Type
A representation of the runtime type of the object.
no setter
inherited
title
→
String
?
final
version
→
String
final
Methods
copyWith
(
{
String
?
name
,
String
?
version
,
String
?
title
})
→
AgentInfo
noSuchMethod
(
Invocation
invocation
)
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap
(
)
→
Map
<
String
,
Object
?
>
toString
(
)
→
String
A string representation of this object.
inherited
Operators
operator ==
(
Object
other
)
→
bool
The equality operator.
inherited
agent_harness package
documentation
agent_harness
AgentInfo class
agent_harness library