ProviderBinaryDescriptor class final
- Annotations
-
- @immutable
Constructors
-
ProviderBinaryDescriptor({required String binaryName, required String environmentKey, required List<
String> validationArguments, required bool validateVersion(String version), String? homeRelativePath, List<String> commonPaths = const <String>[], bool searchNpmGlobal = false, Duration validationTimeout = const Duration(seconds: 10)})
Properties
- binaryName → String
-
final
-
commonPaths
→ List<
String> -
final
- environmentKey → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- homeRelativePath → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- searchNpmGlobal → bool
-
final
- validateVersion → bool Function(String version)
-
final
-
validationArguments
→ List<
String> -
final
- validationTimeout → Duration
-
final
Methods
-
copyWith(
{String? binaryName, String? environmentKey, List< String> ? validationArguments, bool validateVersion(String version)?, Object? homeRelativePath = _absentCopyWithValue, List<String> ? commonPaths, bool? searchNpmGlobal, Duration? validationTimeout}) → ProviderBinaryDescriptor -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited