ProviderBinaryFinder class final
Constructors
- ProviderBinaryFinder({required ProviderBinaryDescriptor descriptor, required ProcessExecutor executor, bool? isWindows})
Properties
- descriptor → ProviderBinaryDescriptor
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
find(
{String? executable, Map< String, String> environment = const <String, String>{}}) → Future<ProviderBinaryResolution?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited